pub trait CommitVerifier { // Required method fn verify( &self, commit_hash: CommitHash, commit: &Commit, payload_hash: Hash, ) -> Result<()>; }
payload_hash has already been re-derived from commit and confirmed to match the value stored on the commit. Implementations should perform only the cryptographic signature check against this hash.
payload_hash
commit